summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/toolbarstate.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /umbrello/umbrello/toolbarstate.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/toolbarstate.h')
-rw-r--r--umbrello/umbrello/toolbarstate.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/umbrello/umbrello/toolbarstate.h b/umbrello/umbrello/toolbarstate.h
index e005c021..4027ce6b 100644
--- a/umbrello/umbrello/toolbarstate.h
+++ b/umbrello/umbrello/toolbarstate.h
@@ -12,8 +12,8 @@
#ifndef TOOLBARSTATE_H
#define TOOLBARSTATE_H
-#include <qevent.h>
-#include <qobject.h>
+#include <tqevent.h>
+#include <tqobject.h>
class QEvent;
class QMouseEvent;
@@ -68,7 +68,7 @@ class UMLWidget;
* @todo Handle, for example, left press, right press, left release, right
* release and other similar strange combinations?
*/
-class ToolBarState: public QObject {
+class ToolBarState: public TQObject {
Q_OBJECT
public:
@@ -102,7 +102,7 @@ public:
* @param ome The received event.
* @see setCurrentElement()
*/
- virtual void mousePress(QMouseEvent *ome);
+ virtual void mousePress(TQMouseEvent *ome);
/**
* Handler for mouse release events.
@@ -113,7 +113,7 @@ public:
*
* @param ome The received event.
*/
- virtual void mouseRelease(QMouseEvent* ome);
+ virtual void mouseRelease(TQMouseEvent* ome);
/**
* Handler for mouse double click events.
@@ -123,7 +123,7 @@ public:
*
* @param ome The received event.
*/
- virtual void mouseDoubleClick(QMouseEvent* ome);
+ virtual void mouseDoubleClick(TQMouseEvent* ome);
/**
* Handler for mouse double click events.
@@ -138,7 +138,7 @@ public:
*
* @param ome The received event.
*/
- virtual void mouseMove(QMouseEvent* ome);
+ virtual void mouseMove(TQMouseEvent* ome);
public slots:
@@ -162,7 +162,7 @@ protected:
/**
* Creates a new ToolBarState.
* UMLView is set as parent of this QObject, and name is left empty.
* Protected to avoid classes other than derived to create objects of this
* class.
*
@@ -313,7 +313,7 @@ protected:
* @param ome The mouse event to transform.
* @param type The type of the event.
*/
- void setMouseEvent(QMouseEvent* ome, const QEvent::Type &type);
+ void setMouseEvent(TQMouseEvent* ome, const TQEvent::Type &type);
/**
* Returns the AssociationWidget at the specified position, or null if there is none.
@@ -323,7 +323,7 @@ protected:
* @return The AssociationWidget at the specified position, or null if there is none.
* @todo Better handling for associations at the same point
*/
- AssociationWidget* getAssociationAt(const QPoint& pos);
+ AssociationWidget* getAssociationAt(const TQPoint& pos);
/**
* Returns the MessageWidget at the specified position, or null if there is none.
@@ -334,7 +334,7 @@ protected:
* @return The MessageWidget at the specified position, or null if there is none.
* @todo Better handling for messages at the same point
*/
- MessageWidget* getMessageAt(const QPoint& pos);
+ MessageWidget* getMessageAt(const TQPoint& pos);
/**
* The UMLView.
@@ -346,7 +346,7 @@ protected:
* This event is the equivalent of the received event after transforming it
* using the inverse world matrix in the UMLView.
*/
- QMouseEvent* m_pMouseEvent;
+ TQMouseEvent* m_pMouseEvent;
private:
@@ -162,7 +162,7 @@ protected:
/**
* Creates a new ToolBarState.
- * UMLView is set as parent of this QObject, and name is left empty.
+ * UMLView is set as parent of this TQObject, and name is left empty.
* Protected to avoid classes other than derived to create objects of this
* class.